@@ -1,6 +1,6 @@
 package Acme::Mitey::Cards::Card;
 
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is );
@@ -11,7 +11,7 @@ use Carp qw( carp );
 
 has deck => (
 	is       => ro,
-	isa      => 'InstanceOf["Acme::Mitey::Cards::Deck"]',
+	isa      => 'Deck',
 	weak_ref => true,
 );
 
