@@ -1,6 +1,6 @@
 package Acme::Mitey::Cards::Card::Face;
 
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is );
@@ -10,13 +10,14 @@ use Acme::Mitey::Cards::Suit;
 
 has suit => (
 	is       => ro,
-	isa      => 'InstanceOf["Acme::Mitey::Cards::Suit"]',
+	isa      => 'Suit',
 	required => true,
+	coerce   => true,
 );
 
 has face => (
 	is       => ro,
-	isa      => 'Enum[ "Jack", "Queen", "King" ]',
+	isa      => 'Character',
 	required => true,
 );
 
