@@ -2,6 +2,7 @@
 
     package Acme::Mitey::Cards::Card::Joker;
     our $USES_MITE = "Mite::Class";
+    our $MITE_SHIM = "Acme::Mitey::Cards::Mite";
     use strict;
     use warnings;
 
@@ -45,7 +46,7 @@
               or require Carp
               && Carp::croak(
                 sprintf "Type check failed in constructor: %s should be %s",
-                "deck", "InstanceOf[\"Acme::Mitey::Cards::Deck\"]" );
+                "deck", "Deck" );
             $self->{"deck"} = $args->{"deck"};
         }
         require Scalar::Util && Scalar::Util::weaken( $self->{"deck"} );
@@ -73,13 +74,17 @@
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        unless ($no_build) {
-            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
-        }
+        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
 
         return $self;
     }
 
+    sub BUILDALL {
+        my $class = ref( $_[0] );
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        $_->(@_) for @{ $meta->{BUILD} || [] };
+    }
+
     sub DESTROY {
         my $self  = shift;
         my $class = ref($self) || $self;
@@ -114,7 +119,8 @@
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
                   map { "$_\::DEMOLISH" } @$linear_isa
             ],
-            HAS_BUILDARGS => $class->can('BUILDARGS'),
+            HAS_BUILDARGS        => $class->can('BUILDARGS'),
+            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
         };
     }
 
