@@ -2,6 +2,7 @@
 
     package Acme::Mitey::Cards::Deck;
     our $USES_MITE = "Mite::Class";
+    our $MITE_SHIM = "Acme::Mitey::Cards::Mite";
     use strict;
     use warnings;
 
@@ -59,40 +60,56 @@
               or require Carp
               && Carp::croak(
                 sprintf "Type check failed in constructor: %s should be %s",
-                "cards", "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]" );
+                "cards", "CardArray" );
             $self->{"cards"} = $args->{"cards"};
         }
         if ( exists $args->{"reverse"} ) {
-            do {
+            (
+                (
+                    do {
 
-                package Acme::Mitey::Cards::Mite;
-                defined( $args->{"reverse"} ) and do {
-                    ref( \$args->{"reverse"} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{"reverse"} ) ) eq 'SCALAR';
+                        package Acme::Mitey::Cards::Mite;
+                        defined( $args->{"reverse"} ) and do {
+                            ref( \$args->{"reverse"} ) eq 'SCALAR'
+                              or ref( \( my $val = $args->{"reverse"} ) ) eq
+                              'SCALAR';
+                        }
+                    }
+                )
+                  && do {
+
+                    package Acme::Mitey::Cards::Mite;
+                    length( $args->{"reverse"} ) > 0;
                 }
-              }
+              )
               or require Carp
               && Carp::croak(
                 sprintf "Type check failed in constructor: %s should be %s",
-                "reverse", "Str" );
+                "reverse", "NonEmptyStr" );
             $self->{"reverse"} = $args->{"reverse"};
         }
         else {
             my $value = do {
                 my $default_value = "plain";
-                do {
+                (
+                    (
+                        do {
 
-                    package Acme::Mitey::Cards::Mite;
-                    defined($default_value) and do {
-                        ref( \$default_value ) eq 'SCALAR'
-                          or ref( \( my $val = $default_value ) ) eq 'SCALAR';
-                    }
-                  }
+                            package Acme::Mitey::Cards::Mite;
+                            defined($default_value) and do {
+                                ref( \$default_value ) eq 'SCALAR'
+                                  or ref( \( my $val = $default_value ) ) eq
+                                  'SCALAR';
+                            }
+                        }
+                    )
+                      && ( length($default_value) > 0 )
+                  )
                   or do {
                     require Carp;
                     Carp::croak(
                         sprintf "Type check failed in default: %s should be %s",
-                        "reverse", "Str"
+                        "reverse", "NonEmptyStr"
                     );
                   };
                 $default_value;
@@ -121,11 +138,10 @@
                     $ok;
                 }
               )
-              or require Carp && Carp::croak(
+              or require Carp
+              && Carp::croak(
                 sprintf "Type check failed in constructor: %s should be %s",
-                "original_cards",
-                "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]"
-              );
+                "original_cards", "CardArray" );
             $self->{"original_cards"} = $args->{"original_cards"};
         }
 
@@ -138,13 +154,17 @@
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        unless ($no_build) {
-            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
-        }
+        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
 
         return $self;
     }
 
+    sub BUILDALL {
+        my $class = ref( $_[0] );
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        $_->(@_) for @{ $meta->{BUILD} || [] };
+    }
+
     sub DESTROY {
         my $self  = shift;
         my $class = ref($self) || $self;
@@ -179,7 +199,8 @@
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
                   map { "$_\::DEMOLISH" } @$linear_isa
             ],
-            HAS_BUILDARGS => $class->can('BUILDARGS'),
+            HAS_BUILDARGS        => $class->can('BUILDARGS'),
+            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
         };
     }
 
@@ -230,8 +251,7 @@
                         Carp::croak(
                             sprintf
                               "Type check failed in default: %s should be %s",
-                            "original_cards",
-                            "ArrayRef[InstanceOf[\"Acme::Mitey::Cards::Card\"]]"
+                            "original_cards", "CardArray"
                         );
                       };
                     $default_value;
