@@ -1,6 +1,6 @@
 package Acme::Mitey::Cards::Set;
 
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is );
@@ -10,7 +10,7 @@ use List::Util ();
 
 has cards => (
 	is       => lazy,
-	isa      => 'ArrayRef[InstanceOf["Acme::Mitey::Cards::Card"]]',
+	isa      => 'CardArray',
 );
 
 sub _build_cards {
