@@ -2,6 +2,7 @@
 
     package Acme::Mitey::Cards::Suit;
     our $USES_MITE = "Mite::Class";
+    our $MITE_SHIM = "Acme::Mitey::Cards::Mite";
     use strict;
     use warnings;
 
@@ -27,18 +28,28 @@
 
         # Initialize attributes
         if ( exists $args->{"name"} ) {
-            do {
+            (
+                (
+                    do {
 
-                package Acme::Mitey::Cards::Mite;
-                defined( $args->{"name"} ) and do {
-                    ref( \$args->{"name"} ) eq 'SCALAR'
-                      or ref( \( my $val = $args->{"name"} ) ) eq 'SCALAR';
+                        package Acme::Mitey::Cards::Mite;
+                        defined( $args->{"name"} ) and do {
+                            ref( \$args->{"name"} ) eq 'SCALAR'
+                              or ref( \( my $val = $args->{"name"} ) ) eq
+                              'SCALAR';
+                        }
+                    }
+                )
+                  && do {
+
+                    package Acme::Mitey::Cards::Mite;
+                    length( $args->{"name"} ) > 0;
                 }
-              }
+              )
               or require Carp
               && Carp::croak(
                 sprintf "Type check failed in constructor: %s should be %s",
-                "name", "Str" );
+                "name", "NonEmptyStr" );
             $self->{"name"} = $args->{"name"};
         }
         else { require Carp; Carp::croak("Missing key in constructor: name") }
@@ -84,13 +95,17 @@
             "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
 
         # Call BUILD methods
-        unless ($no_build) {
-            $_->( $self, $args ) for @{ $meta->{BUILD} || [] };
-        }
+        $self->BUILDALL($args) if ( !$no_build and @{ $meta->{BUILD} || [] } );
 
         return $self;
     }
 
+    sub BUILDALL {
+        my $class = ref( $_[0] );
+        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
+        $_->(@_) for @{ $meta->{BUILD} || [] };
+    }
+
     sub DESTROY {
         my $self  = shift;
         my $class = ref($self) || $self;
@@ -125,7 +140,8 @@
                 map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
                   map { "$_\::DEMOLISH" } @$linear_isa
             ],
-            HAS_BUILDARGS => $class->can('BUILDARGS'),
+            HAS_BUILDARGS        => $class->can('BUILDARGS'),
+            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
         };
     }
 
